@@ -1,4 +1,4 @@
-package App::DistSync; # $Id: DistSync.pm 22 2015-11-18 12:54:18Z abalama $
+package App::DistSync; # $Id: DistSync.pm 23 2017-05-08 13:44:30Z abalama $
 use strict;
 
 =head1 NAME
@@ -7,7 +7,7 @@ App::DistSync - Utility synchronization of the mirror distribution-sites
 
 =head1 VERSION
 
-Version 1.03
+Version 1.04
 
 =head1 SYNOPSIS
 
@@ -133,7 +133,7 @@ See C<LICENSE> file
 =cut
 
 use vars qw/$VERSION/;
-$VERSION = '1.03';
+$VERSION = '1.04';
 
 use Carp;
 use File::Basename;
@@ -143,7 +143,7 @@ use File::Find;
 use File::Path;
 use YAML::Tiny;
 use URI;
-use LWP::Simple;
+use LWP::Simple qw/$ua head mirror/;
 
 use base qw/Exporter/;
 our @EXPORT = qw/
@@ -162,6 +162,7 @@ our @EXPORT_OK = qw/
 
 use constant {
     TEMPFILE    => sprintf("distsync_%s.tmp", $$),
+    TIMEOUT     => 30,
     METAFILE    => 'META',
     MANIFEST    => 'MANIFEST',
     MANISKIP    => 'MANIFEST.SKIP',
@@ -213,6 +214,7 @@ sub new {
     
     $props{stamp} = time;
     $props{pid} ||= $$;
+    $props{timeout} //= TIMEOUT;
     
     # Directories check
     my $dir = $props{dir};
@@ -248,6 +250,14 @@ sub new {
     $props{manidel}  = maniread($props{file_manidel});
     $props{mirrors}  = maniread($props{file_mirrors});
     
+    # TimeOut
+    my $to = $props{timeout};
+    if ($to && $to =~ /^[0-9]{1,11}$/) {
+        $ua->timeout($to);
+    } else {
+        croak(sprintf("Can't use specified timeout value: %s", $to));
+    }
+    
     my $self = bless({%props}, $class);
     return $self;
 }
